<script setup>
import AuthenticatedLayout from '@/Layouts/AuthenticatedLayout.vue';
import ProductFilter from '@/components/ProductFilter.vue'

import { ref, onMounted, computed } from 'vue';
import { Head, usePage, useForm } from '@inertiajs/vue3';

const page = usePage();
console.log(page);
const userDetails = computed(() => page.props.auth || []);
const addresses = computed(() => page.props.addresses || []);
const cart = computed(() => page.props.cart || []);
const isMobile = ref(window.innerWidth <= 768);
const flashMessage = ref('');
const dropShip = ref(false);
const cartShipping = ref('1');
const cartCustomerPO = ref('');
const cartComment = ref('');
const orderTotal = ref('');
const cartAddress = ref('primary');
const btnClass = "inline-flex items-center px-3 py-2 border border-transparent text-sm leading-4 font-medium rounded-md hover:text-gray-700 focus:outline-none transition ease-in-out duration-150";
const dropShipCompany = ref('');
const dropShipContact = ref('');
const dropShipPhone = ref('');
const dropShipFax = ref('');
const dropShipAddress1 = ref('');
const dropShipAddress2 = ref('');
const dropShipCity = ref('');
const dropShipCountry = ref('');
const dropShipState = ref('');
const dropShipZip = ref('');

const form = useForm({
    user_id: page.props.auth.user.id,
    price: 0,
    shipping_tracking: '',
    total_price: 0,
    comment: '',
    customer_po: '',
    tax: 0,
    shipping_id: 0,
    shipping_price: 0,
    addressID: 0,
    company: '',
    contact: '',
    phone: '',
    fax: '',
    address1: '',
    address2: '',
    city: '',
    state: '',
    zip: '',
    country: '',
});

const handleResize = () => {
    isMobile.value = window.innerWidth <= 768;
}

const cartTotal = () => {
    let total = 0;
    cart.value.forEach(item => {
        total += item.price * item.cart_qty;
    });
    total = total.toFixed(2);
    orderTotal.value = total;
    return total;
};

onMounted(() => {
    window.addEventListener('resize', handleResize);
    handleResize();
    orderTotal.value = cartTotal();
    console.log(dropShip);
});

const saveOrder = () => {
    form.price = cartTotal();
    form.total_price = orderTotal;
    form.comment = cartComment;
    form.customer_po = cartCustomerPO;
    form.shipping_id = cartShipping;
    form.addressID = cartAddress;

    form.post(route('save.order'), {
        onSuccess: () => {
            flashMessage.value = "Order Success";
        },
        onError: (error) => {
            console.error(error);
        }
    });
};

const singleProduct = (item_number) => {
    window.location.href = `/product/${item_number}`;
};

const updateDropShip = () => {
    form.company = dropShipCompany;
    form.contact = dropShipContact;
    form.phone = dropShipPhone;
    form.fax = dropShipFax;
    form.address1 = dropShipAddress1;
    form.address2 = dropShipAddress2;
    form.country = dropShipCountry;
    form.city = dropShipCity;
    form.state = dropShipState;
    form.zip = dropShipZip;

    form.post(route('save.address'), {
        onSuccess: () => {
            flashMessage.value = "Drop Address added";

            addresses.value.forEach(address => {
                if(address.company == dropShipCompany.value) {
                    cartAddress.value = address.id;
                }
            });
        },
        onError: (error) => {
            console.error(error);
        }
    });
};

const isSelected = (address) => {
    return address.company === 'oo';
}
</script>

<template>
    <Head title="Checkout" />

    <AuthenticatedLayout>
        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight">Checkout</h2>
        </template>

        <div class="py-12 container">
            <div class="row">
                <div v-if="flashMessage" class="col-12 mx-auto sm:px-6 lg:px-8 font-bold text-red-600">
                    <div class="form-row mb-6 alert alert-success">
                        <h4>{{ flashMessage }}</h4>
                    </div>
                </div>

                <div class="col-lg-9 col-md-12 col-sm-12 col-12 cart_details">
                    <div class="content-box sm:rounded-lg cart-details-box">
                        <h3>Cart Detail</h3>
                        <table class="table table-striped" style="width: 100%;">
                            <thead>
                                <tr>
                                    <th>Qty</th>
                                    <th>ItemNumber</th>
                                    <th v-if="!isMobile">Item Description</th>
                                    <th>Price</th>
                                </tr>
                            </thead>
                            <tbody>
                                <tr v-for="product in cart" :key="product.id">
                                    <td>{{ product.cart_qty }}</td>
                                    <td><a href="#" @click="singleProduct(product.item_number)">{{ product.item_number }}</a></td>
                                    <td v-if="!isMobile" >{{ product.item_description }}</td>
                                    <td>{{ product.price }}</td>
                                </tr>
                            </tbody>
                        </table>
                    </div>
                </div>
                <div class="col-lg-3 col-md-12 col-sm-12 col-12 order_summary">
                    <div class="content-box sm:rounded-lg order-summary cart-details-box">
                        <h3>Order Summary</h3>
                        <p><span class="text-left">Subtotal</span> <span class="text-right">${{ cartTotal() }}</span></p>
                        <p><span class="text-left">Shipping</span> <span class="text-right">$0.00</span></p>
                        <p><span class="text-left">Tax</span> <span class="text-right">$0.00</span></p>
                        <hr class="border-gray-300" />
                        <p><b><span class="text-left">Total</span> <span class="text-right">${{ orderTotal }}</span></b></p>
                    </div>
                </div>
            </div>
            <div class="row shipping_details">
                <div class="col-lg-5 col-md-6 col-sm-12 col-12 cart_details">
                    <div class="content-box sm:rounded-lg cart-details-box">
                        <h3>Shipping Infomration</h3>
                        <table style="width: 100%;">
                            <tr>
                                <td><input type="checkbox" v-model="dropShip" :value="dropShip" id="dropship" /> <label for="dropship">Drop ship address</label></td>
                                <td></td>
                            </tr>
                        </table>
                        <table style="width: 100%;" v-if="dropShip" class="drop-shipping-table">
                            <tr>
                                <td>Company</td>
                                <td><input type="text" v-model="dropShipCompany" /></td>
                            </tr>
                            <tr>
                                <td>Contact</td>
                                <td><input type="text" v-model="dropShipContact" /></td>
                            </tr>
                            <tr>
                                <td>Phone</td>
                                <td><input type="text" v-model="dropShipPhone" /></td>
                            </tr>
                            <tr>
                                <td>Fax</td>
                                <td><input type="text" v-model="dropShipFax" /></td>
                            </tr>
                            <tr>
                                <td>Address 1</td>
                                <td><input type="text" v-model="dropShipAddress1" /></td>
                            </tr>
                            <tr>
                                <td>Address 2</td>
                                <td><input type="text" v-model="dropShipAddress2" /></td>
                            </tr>
                            <tr>
                                <td>City</td>
                                <td><input type="text" v-model="dropShipCity" /></td>
                            </tr>
                            <tr>
                                <td>Country</td>
                                <td><input type="text" v-model="dropShipCountry" /></td>
                            </tr>
                            <tr>
                                <td>State</td>
                                <td><input type="text" v-model="dropShipState" /></td>
                            </tr>
                            <tr>
                                <td>Zip</td>
                                <td><input type="text" v-model="dropShipZip" /></td>
                            </tr>
                            <tr>
                                <td></td>
                                <td><button class="btn btn-blue" :class="btnClass" @click="updateDropShip">Update</button></td>
                            </tr>
                        </table>
                        <table class="table table-striped" style="width: 100%;" v-else>
                            <tr>
                                <td>Address Code</td>
                                <td>
                                    <select v-model="cartAddress">
                                        <option value="primary">Primary</option>
                                        <option v-for="address in addresses" :key="address.id" :value="address.id" :selected="isSelected(address)">{{ address.company }}</option>
                                    </select>
                                </td>
                            </tr>
                            <tr>
                                <td>Company</td>
                                <td>
                                    {{cartAddress == 'primary' ? userDetails.user.company : addresses.find(item => item.id == cartAddress).company }}
                                </td>
                            </tr>
                            <tr>
                                <td>Contact</td>
                                <td>
                                    {{cartAddress == 'primary' ? userDetails.user.name : addresses.find(item => item.id == cartAddress).name }}
                                </td>
                            </tr>
                            <tr>
                                <td>Phone</td>
                                <td>
                                    {{cartAddress == 'primary' ? userDetails.user.phone : addresses.find(item => item.id == cartAddress).phone }}
                                </td>
                            </tr>
                            <tr>
                                <td>Fax</td>
                                <td>
                                    {{cartAddress == 'primary' ? userDetails.user.fax : addresses.find(item => item.id == cartAddress).fax }}
                                </td>
                            </tr>
                            <tr>
                                <td>Address 1</td>
                                <td>
                                    {{cartAddress == 'primary' ? userDetails.user.address1 : addresses.find(item => item.id == cartAddress).address1 }}
                                </td>
                            </tr>
                            <tr>
                                <td>Address 2</td>
                                <td>
                                    {{cartAddress == 'primary' ? userDetails.user.address2 : addresses.find(item => item.id == cartAddress).address2 }}
                                </td>
                            </tr>
                            <tr>
                                <td>City</td>
                                <td>
                                    {{cartAddress == 'primary' ? userDetails.user.city : addresses.find(item => item.id == cartAddress).city }}
                                </td>
                            </tr>
                            <tr>
                                <td>Country</td>
                                <td>
                                    {{cartAddress == 'primary' ? userDetails.user.country : addresses.find(item => item.id == cartAddress).country }}
                                </td>
                            </tr>
                            <tr>
                                <td>State</td>
                                <td>
                                    {{cartAddress == 'primary' ? userDetails.user.state : addresses.find(item => item.id == cartAddress).state }}
                                </td>
                            </tr>
                            <tr>
                                <td>Zip</td>
                                <td>
                                    {{cartAddress == 'primary' ? userDetails.user.postal : addresses.find(item => item.id == cartAddress).zip }}
                                </td>
                            </tr>
                        </table>
                    </div>
                </div>
                <div class="col-lg-4 col-md-6 col-sm-12 col-12 cart_details">
                    <div class="content-box sm:rounded-lg cart-details-box">
                        <h3>Shipping Option</h3>
                        <table class="table shipping-table">
                            <tr>
                                <td>Shipping Method</td>
                                <td>
                                    <select v-model="cartShipping">
                                        <option value="1">20. Next Scheduled Delivery</option>
                                    </select>
                                </td>
                            </tr>
                            <tr>
                                <td>Customer PO</td>
                                <td><input type="text" v-model="cartCustomerPO" /></td>
                            </tr>
                        </table>
                    </div>
                </div>
                <div class="col-lg-3 col-md-12 col-sm-12 col-12  order_summary">
                    <div class="content-box sm:rounded-lg finish-order cart-details-box">
                        <h4>Comment</h4>
                        <textarea v-model="cartComment"></textarea>
                        <button @click="saveOrder" :class="btnClass">Finish Order</button>
                    </div>
                </div>
            </div>
        </div>
    </AuthenticatedLayout>
</template>
<style scoped>
table tr td {
    max-width: 200px;
}
.shipping-table tr td{
    width: auto;
    max-width: fit-content;
}
.cart_qty input {
    width: 70px;
    padding: 0 5px;
    height: 33px;
}
.cart-details-box{
    height: calc(100%);
}
.cart_details h3, .order_summary h3, .cart_details table tr th {
    padding: 10px;
}
.cart_details table tr td {
    padding: 5px 10px;
}
.cart_details h3, .order_summary h3 {
    font-size: 20px;
    font-weight: bold;
}
.order_summary p {
    padding: 5px 10px;
}
.order_summary p span[data-v-cb17554d] {
	width: 49%;
	display: inline-block;
}
.shipping_details {
    margin-top: 30px;
}
.order-summary{
    background: var(--primary);
  color: var(--white);
}
.finish-order textarea {
	width: 100%;
	background: #f3f4f6;
	border: none;
	margin: 14px 0;
}

@media(max-width:1280px){
.order_summary p span{
	width: 100%;
	display: block;
	text-align: left !important;
}
@media(max-width:991px){
.cart_details {
	margin-bottom: 30px;
}
}
}
</style>
